***********
Vectorizers
***********

HFTextVectorizer
================

.. _hftextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.huggingface

.. autoclass:: HFTextVectorizer
   :show-inheritance:
   :members:


OpenAITextVectorizer
====================

.. _openaitextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.openai

.. autoclass:: OpenAITextVectorizer
   :show-inheritance:
   :members:


AzureOpenAITextVectorizer
=========================

.. _azureopenaitextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.azureopenai

.. autoclass:: AzureOpenAITextVectorizer
   :show-inheritance:
   :members:


VertexAITextVectorizer
======================

.. _vertexaitextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.vertexai

.. autoclass:: VertexAITextVectorizer
   :show-inheritance:
   :members:


CohereTextVectorizer
====================

.. _coheretextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.cohere

.. autoclass:: CohereTextVectorizer
   :show-inheritance:
   :members:


BedrockTextVectorizer
=====================

.. _bedrocktextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.bedrock

.. autoclass:: BedrockTextVectorizer
   :show-inheritance:
   :members:


CustomTextVectorizer
====================

.. _customtextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.custom

.. autoclass:: CustomTextVectorizer
   :show-inheritance:
   :members:


VoyageAITextVectorizer
======================

.. _voyageaitextvectorizer_api:

.. currentmodule:: redisvl.utils.vectorize.text.voyageai

.. autoclass:: VoyageAITextVectorizer
   :show-inheritance:
   :members:
